;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "repo-grep" "20250826.1109"
  "Project-wide grep search."
  '((emacs "25.1"))
  :url "https://github.com/BHFock/repo-grep"
  :commit "98dd4b492d93b8d13f9bc7b80efe91577c13e779"
  :revdesc "98dd4b492d93"
  :keywords '("tools" "search" "grep" "convenience" "project"))
